import * as anchor from "@project-serum/anchor";
import { Program, Provider } from "@project-serum/anchor";
import { SplTokenMetadata, InstructionResult, BigInstructionResult, ICreateArweaveUrlArgs } from "@strata-foundation/spl-utils";
import { PublicKey, Signer, TransactionInstruction } from "@solana/web3.js";
import { SplTokenCollectiveIDL } from "./generated/spl-token-collective";
import { SplTokenBonding, CreateTokenBondingArgs } from "@strata-foundation/spl-token-bonding";
export * from "./generated/spl-token-collective";
export interface CreateCollectiveArgs {
    payer?: PublicKey;
    metadata?: ICreateArweaveUrlArgs & {
        uploadUrl?: string;
    };
    bonding?: CreateTokenBondingArgs;
    mint?: PublicKey;
    mintAuthority?: PublicKey;
    authority?: PublicKey;
    config: ICollectiveConfig;
}
export interface TokenBondingParams {
    buyBaseRoyaltyPercentage: number;
    buyTargetRoyaltyPercentage: number;
    sellBaseRoyaltyPercentage: number;
    sellTargetRoyaltyPercentage: number;
    targetMintDecimals?: number;
    buyBaseRoyalties?: PublicKey;
    buyBaseRoyaltiesOwner?: PublicKey;
    buyTargetRoyalties?: PublicKey;
    buyTargetRoyaltiesOwner?: PublicKey;
    sellBaseRoyalties?: PublicKey;
    sellBaseRoyaltiesOwner?: PublicKey;
    sellTargetRoyalties?: PublicKey;
    sellTargetRoyaltiesOwner?: PublicKey;
}
export interface CreateSocialTokenArgs {
    ignoreIfExists: boolean;
    payer?: PublicKey;
    collective?: PublicKey;
    name?: PublicKey;
    nameClass?: PublicKey;
    nameParent?: PublicKey;
    tokenName: string;
    symbol?: string;
    owner?: PublicKey;
    curve?: PublicKey;
    tokenBondingParams: TokenBondingParams;
}
export interface ClaimSocialTokenArgs {
    payer?: PublicKey;
    owner: PublicKey;
    tokenRef: PublicKey;
    symbol?: string;
    buyBaseRoyalties?: PublicKey;
    buyTargetRoyalties?: PublicKey;
    sellBaseRoyalties?: PublicKey;
    sellTargetRoyalties?: PublicKey;
    ignoreMissingName?: boolean;
}
export interface IRoyaltySetting {
    ownedByName?: boolean;
    address?: number;
}
export interface ITokenBondingSettings {
    curve?: PublicKey;
    minSellBaseRoyaltyPercentage?: number;
    minSellTargetRoyaltyPercentage?: number;
    maxSellBaseRoyaltyPercentage?: number;
    maxSellTargetRoyaltyPercentage?: number;
    minBuyBaseRoyaltyPercentage?: number;
    minBuyTargetRoyaltyPercentage?: number;
    maxBuyBaseRoyaltyPercentage?: number;
    maxBuyTargetRoyaltyPercentage?: number;
    targetMintDecimals?: number;
    buyBaseRoyalties?: IRoyaltySetting;
    sellBaseRoyalties?: IRoyaltySetting;
    buyTargetRoyalties?: IRoyaltySetting;
    sellTargetRoyalties?: IRoyaltySetting;
    minPurchaseCap?: number;
    maxPurchaseCap?: number;
    minMintCap?: number;
    maxMintCap?: number;
}
export interface ITokenMetadataSettings {
    symbol?: string;
    uri?: string;
    nameIsNameServiceName?: boolean;
}
export interface ICollectiveConfig {
    isOpen: boolean;
    unclaimedTokenBondingSettings?: ITokenBondingSettings;
    claimedTokenBondingSettings?: ITokenBondingSettings;
    unclaimedTokenMetadataSettings?: ITokenMetadataSettings;
}
export declare class SplTokenCollective {
    program: Program<SplTokenCollectiveIDL>;
    splTokenBondingProgram: SplTokenBonding;
    splTokenMetadata: SplTokenMetadata;
    provider: Provider;
    static ID: anchor.web3.PublicKey;
    static OPEN_COLLECTIVE_ID: anchor.web3.PublicKey;
    static OPEN_COLLECTIVE_BONDING_ID: anchor.web3.PublicKey;
    static OPEN_COLLECTIVE_MINT_ID: anchor.web3.PublicKey;
    static init(provider: Provider, splCollectiveProgramId?: PublicKey, splTokenBondingProgramId?: PublicKey): Promise<SplTokenCollective>;
    constructor(opts: {
        provider: Provider;
        program: Program<SplTokenCollectiveIDL>;
        splTokenBondingProgram: SplTokenBonding;
        splTokenMetadata: SplTokenMetadata;
    });
    get programId(): anchor.web3.PublicKey;
    get rpc(): anchor.RpcNamespace<SplTokenCollectiveIDL, {
        name: "initializeCollectiveV0";
        accounts: [{
            name: "collective";
            isMut: true;
            isSigner: false;
        }, {
            name: "mint";
            isMut: false;
            isSigner: false;
        }, {
            name: "mintAuthority";
            isMut: false;
            isSigner: true;
        }, {
            name: "payer";
            isMut: true;
            isSigner: true;
        }, {
            name: "systemProgram";
            isMut: false;
            isSigner: false;
        }, {
            name: "rent";
            isMut: false;
            isSigner: false;
        }];
        args: [{
            name: "args";
            type: {
                defined: "InitializeCollectiveV0Args";
            };
        }];
    } | {
        name: "initializeOwnedSocialTokenV0";
        accounts: [{
            name: "initializeArgs";
            accounts: [{
                name: "payer";
                isMut: true;
                isSigner: true;
            }, {
                name: "collective";
                isMut: false;
                isSigner: false;
            }, {
                name: "tokenBonding";
                isMut: false;
                isSigner: false;
            }, {
                name: "tokenMetadata";
                isMut: false;
                isSigner: false;
            }, {
                name: "baseMint";
                isMut: false;
                isSigner: false;
            }, {
                name: "targetMint";
                isMut: false;
                isSigner: false;
            }, {
                name: "buyBaseRoyalties";
                isMut: false;
                isSigner: false;
            }, {
                name: "buyTargetRoyalties";
                isMut: false;
                isSigner: false;
            }, {
                name: "sellBaseRoyalties";
                isMut: false;
                isSigner: false;
            }, {
                name: "sellTargetRoyalties";
                isMut: false;
                isSigner: false;
            }, {
                name: "systemProgram";
                isMut: false;
                isSigner: false;
            }, {
                name: "rent";
                isMut: false;
                isSigner: false;
            }, {
                name: "clock";
                isMut: false;
                isSigner: false;
            }];
        }, {
            name: "authority";
            isMut: false;
            isSigner: false;
        }, {
            name: "payer";
            isMut: true;
            isSigner: true;
        }, {
            name: "tokenRef";
            isMut: true;
            isSigner: false;
        }, {
            name: "reverseTokenRef";
            isMut: true;
            isSigner: false;
        }, {
            name: "owner";
            isMut: false;
            isSigner: true;
        }, {
            name: "systemProgram";
            isMut: false;
            isSigner: false;
        }, {
            name: "rent";
            isMut: false;
            isSigner: false;
        }];
        args: [{
            name: "args";
            type: {
                defined: "InitializeSocialTokenV0Args";
            };
        }];
    } | {
        name: "initializeUnclaimedSocialTokenV0";
        accounts: [{
            name: "initializeArgs";
            accounts: [{
                name: "payer";
                isMut: true;
                isSigner: true;
            }, {
                name: "collective";
                isMut: false;
                isSigner: false;
            }, {
                name: "tokenBonding";
                isMut: false;
                isSigner: false;
            }, {
                name: "tokenMetadata";
                isMut: false;
                isSigner: false;
            }, {
                name: "baseMint";
                isMut: false;
                isSigner: false;
            }, {
                name: "targetMint";
                isMut: false;
                isSigner: false;
            }, {
                name: "buyBaseRoyalties";
                isMut: false;
                isSigner: false;
            }, {
                name: "buyTargetRoyalties";
                isMut: false;
                isSigner: false;
            }, {
                name: "sellBaseRoyalties";
                isMut: false;
                isSigner: false;
            }, {
                name: "sellTargetRoyalties";
                isMut: false;
                isSigner: false;
            }, {
                name: "systemProgram";
                isMut: false;
                isSigner: false;
            }, {
                name: "rent";
                isMut: false;
                isSigner: false;
            }, {
                name: "clock";
                isMut: false;
                isSigner: false;
            }];
        }, {
            name: "authority";
            isMut: false;
            isSigner: true;
        }, {
            name: "payer";
            isMut: true;
            isSigner: true;
        }, {
            name: "tokenRef";
            isMut: true;
            isSigner: false;
        }, {
            name: "reverseTokenRef";
            isMut: true;
            isSigner: false;
        }, {
            name: "tokenMetadata";
            isMut: false;
            isSigner: false;
        }, {
            name: "name";
            isMut: false;
            isSigner: false;
        }, {
            name: "systemProgram";
            isMut: false;
            isSigner: false;
        }, {
            name: "rent";
            isMut: false;
            isSigner: false;
        }];
        args: [{
            name: "args";
            type: {
                defined: "InitializeSocialTokenV0Args";
            };
        }];
    } | {
        name: "claimSocialTokenV0";
        accounts: [{
            name: "payer";
            isMut: false;
            isSigner: true;
        }, {
            name: "collective";
            isMut: false;
            isSigner: false;
        }, {
            name: "tokenRef";
            isMut: true;
            isSigner: false;
        }, {
            name: "newTokenRef";
            isMut: true;
            isSigner: false;
        }, {
            name: "reverseTokenRef";
            isMut: true;
            isSigner: false;
        }, {
            name: "tokenBonding";
            isMut: true;
            isSigner: false;
        }, {
            name: "tokenMetadata";
            isMut: true;
            isSigner: false;
        }, {
            name: "tokenBondingAuthority";
            isMut: false;
            isSigner: false;
        }, {
            name: "metadataUpdateAuthority";
            isMut: false;
            isSigner: false;
        }, {
            name: "name";
            isMut: false;
            isSigner: false;
        }, {
            name: "owner";
            isMut: true;
            isSigner: true;
        }, {
            name: "baseMint";
            isMut: false;
            isSigner: false;
        }, {
            name: "targetMint";
            isMut: false;
            isSigner: false;
        }, {
            name: "buyBaseRoyalties";
            isMut: true;
            isSigner: false;
        }, {
            name: "buyTargetRoyalties";
            isMut: true;
            isSigner: false;
        }, {
            name: "sellBaseRoyalties";
            isMut: true;
            isSigner: false;
        }, {
            name: "sellTargetRoyalties";
            isMut: true;
            isSigner: false;
        }, {
            name: "newBuyBaseRoyalties";
            isMut: true;
            isSigner: false;
        }, {
            name: "newBuyTargetRoyalties";
            isMut: true;
            isSigner: false;
        }, {
            name: "newSellBaseRoyalties";
            isMut: true;
            isSigner: false;
        }, {
            name: "newSellTargetRoyalties";
            isMut: true;
            isSigner: false;
        }, {
            name: "royaltiesOwner";
            isMut: false;
            isSigner: false;
        }, {
            name: "tokenBondingProgram";
            isMut: false;
            isSigner: false;
        }, {
            name: "tokenProgram";
            isMut: false;
            isSigner: false;
        }, {
            name: "tokenMetadataProgram";
            isMut: false;
            isSigner: false;
        }, {
            name: "systemProgram";
            isMut: false;
            isSigner: false;
        }, {
            name: "rent";
            isMut: false;
            isSigner: false;
        }];
        args: [{
            name: "args";
            type: {
                defined: "ClaimSocialTokenV0Args";
            };
        }];
    } | {
        name: "updateTokenBondingV0";
        accounts: [{
            name: "collective";
            isMut: false;
            isSigner: false;
        }, {
            name: "authority";
            isMut: false;
            isSigner: false;
        }, {
            name: "reverseTokenRef";
            isMut: false;
            isSigner: false;
        }, {
            name: "tokenBonding";
            isMut: true;
            isSigner: false;
        }, {
            name: "tokenBondingAuthority";
            isMut: false;
            isSigner: false;
        }, {
            name: "owner";
            isMut: false;
            isSigner: true;
        }, {
            name: "tokenBondingProgram";
            isMut: false;
            isSigner: false;
        }, {
            name: "baseMint";
            isMut: false;
            isSigner: false;
        }, {
            name: "targetMint";
            isMut: false;
            isSigner: false;
        }, {
            name: "buyBaseRoyalties";
            isMut: false;
            isSigner: false;
        }, {
            name: "buyTargetRoyalties";
            isMut: false;
            isSigner: false;
        }, {
            name: "sellBaseRoyalties";
            isMut: false;
            isSigner: false;
        }, {
            name: "sellTargetRoyalties";
            isMut: false;
            isSigner: false;
        }];
        args: [{
            name: "args";
            type: {
                defined: "UpdateTokenBondingV0ArgsWrapper";
            };
        }];
    }>;
    get instruction(): anchor.InstructionNamespace<SplTokenCollectiveIDL, {
        name: "initializeCollectiveV0";
        accounts: [{
            name: "collective";
            isMut: true;
            isSigner: false;
        }, {
            name: "mint";
            isMut: false;
            isSigner: false;
        }, {
            name: "mintAuthority";
            isMut: false;
            isSigner: true;
        }, {
            name: "payer";
            isMut: true;
            isSigner: true;
        }, {
            name: "systemProgram";
            isMut: false;
            isSigner: false;
        }, {
            name: "rent";
            isMut: false;
            isSigner: false;
        }];
        args: [{
            name: "args";
            type: {
                defined: "InitializeCollectiveV0Args";
            };
        }];
    } | {
        name: "initializeOwnedSocialTokenV0";
        accounts: [{
            name: "initializeArgs";
            accounts: [{
                name: "payer";
                isMut: true;
                isSigner: true;
            }, {
                name: "collective";
                isMut: false;
                isSigner: false;
            }, {
                name: "tokenBonding";
                isMut: false;
                isSigner: false;
            }, {
                name: "tokenMetadata";
                isMut: false;
                isSigner: false;
            }, {
                name: "baseMint";
                isMut: false;
                isSigner: false;
            }, {
                name: "targetMint";
                isMut: false;
                isSigner: false;
            }, {
                name: "buyBaseRoyalties";
                isMut: false;
                isSigner: false;
            }, {
                name: "buyTargetRoyalties";
                isMut: false;
                isSigner: false;
            }, {
                name: "sellBaseRoyalties";
                isMut: false;
                isSigner: false;
            }, {
                name: "sellTargetRoyalties";
                isMut: false;
                isSigner: false;
            }, {
                name: "systemProgram";
                isMut: false;
                isSigner: false;
            }, {
                name: "rent";
                isMut: false;
                isSigner: false;
            }, {
                name: "clock";
                isMut: false;
                isSigner: false;
            }];
        }, {
            name: "authority";
            isMut: false;
            isSigner: false;
        }, {
            name: "payer";
            isMut: true;
            isSigner: true;
        }, {
            name: "tokenRef";
            isMut: true;
            isSigner: false;
        }, {
            name: "reverseTokenRef";
            isMut: true;
            isSigner: false;
        }, {
            name: "owner";
            isMut: false;
            isSigner: true;
        }, {
            name: "systemProgram";
            isMut: false;
            isSigner: false;
        }, {
            name: "rent";
            isMut: false;
            isSigner: false;
        }];
        args: [{
            name: "args";
            type: {
                defined: "InitializeSocialTokenV0Args";
            };
        }];
    } | {
        name: "initializeUnclaimedSocialTokenV0";
        accounts: [{
            name: "initializeArgs";
            accounts: [{
                name: "payer";
                isMut: true;
                isSigner: true;
            }, {
                name: "collective";
                isMut: false;
                isSigner: false;
            }, {
                name: "tokenBonding";
                isMut: false;
                isSigner: false;
            }, {
                name: "tokenMetadata";
                isMut: false;
                isSigner: false;
            }, {
                name: "baseMint";
                isMut: false;
                isSigner: false;
            }, {
                name: "targetMint";
                isMut: false;
                isSigner: false;
            }, {
                name: "buyBaseRoyalties";
                isMut: false;
                isSigner: false;
            }, {
                name: "buyTargetRoyalties";
                isMut: false;
                isSigner: false;
            }, {
                name: "sellBaseRoyalties";
                isMut: false;
                isSigner: false;
            }, {
                name: "sellTargetRoyalties";
                isMut: false;
                isSigner: false;
            }, {
                name: "systemProgram";
                isMut: false;
                isSigner: false;
            }, {
                name: "rent";
                isMut: false;
                isSigner: false;
            }, {
                name: "clock";
                isMut: false;
                isSigner: false;
            }];
        }, {
            name: "authority";
            isMut: false;
            isSigner: true;
        }, {
            name: "payer";
            isMut: true;
            isSigner: true;
        }, {
            name: "tokenRef";
            isMut: true;
            isSigner: false;
        }, {
            name: "reverseTokenRef";
            isMut: true;
            isSigner: false;
        }, {
            name: "tokenMetadata";
            isMut: false;
            isSigner: false;
        }, {
            name: "name";
            isMut: false;
            isSigner: false;
        }, {
            name: "systemProgram";
            isMut: false;
            isSigner: false;
        }, {
            name: "rent";
            isMut: false;
            isSigner: false;
        }];
        args: [{
            name: "args";
            type: {
                defined: "InitializeSocialTokenV0Args";
            };
        }];
    } | {
        name: "claimSocialTokenV0";
        accounts: [{
            name: "payer";
            isMut: false;
            isSigner: true;
        }, {
            name: "collective";
            isMut: false;
            isSigner: false;
        }, {
            name: "tokenRef";
            isMut: true;
            isSigner: false;
        }, {
            name: "newTokenRef";
            isMut: true;
            isSigner: false;
        }, {
            name: "reverseTokenRef";
            isMut: true;
            isSigner: false;
        }, {
            name: "tokenBonding";
            isMut: true;
            isSigner: false;
        }, {
            name: "tokenMetadata";
            isMut: true;
            isSigner: false;
        }, {
            name: "tokenBondingAuthority";
            isMut: false;
            isSigner: false;
        }, {
            name: "metadataUpdateAuthority";
            isMut: false;
            isSigner: false;
        }, {
            name: "name";
            isMut: false;
            isSigner: false;
        }, {
            name: "owner";
            isMut: true;
            isSigner: true;
        }, {
            name: "baseMint";
            isMut: false;
            isSigner: false;
        }, {
            name: "targetMint";
            isMut: false;
            isSigner: false;
        }, {
            name: "buyBaseRoyalties";
            isMut: true;
            isSigner: false;
        }, {
            name: "buyTargetRoyalties";
            isMut: true;
            isSigner: false;
        }, {
            name: "sellBaseRoyalties";
            isMut: true;
            isSigner: false;
        }, {
            name: "sellTargetRoyalties";
            isMut: true;
            isSigner: false;
        }, {
            name: "newBuyBaseRoyalties";
            isMut: true;
            isSigner: false;
        }, {
            name: "newBuyTargetRoyalties";
            isMut: true;
            isSigner: false;
        }, {
            name: "newSellBaseRoyalties";
            isMut: true;
            isSigner: false;
        }, {
            name: "newSellTargetRoyalties";
            isMut: true;
            isSigner: false;
        }, {
            name: "royaltiesOwner";
            isMut: false;
            isSigner: false;
        }, {
            name: "tokenBondingProgram";
            isMut: false;
            isSigner: false;
        }, {
            name: "tokenProgram";
            isMut: false;
            isSigner: false;
        }, {
            name: "tokenMetadataProgram";
            isMut: false;
            isSigner: false;
        }, {
            name: "systemProgram";
            isMut: false;
            isSigner: false;
        }, {
            name: "rent";
            isMut: false;
            isSigner: false;
        }];
        args: [{
            name: "args";
            type: {
                defined: "ClaimSocialTokenV0Args";
            };
        }];
    } | {
        name: "updateTokenBondingV0";
        accounts: [{
            name: "collective";
            isMut: false;
            isSigner: false;
        }, {
            name: "authority";
            isMut: false;
            isSigner: false;
        }, {
            name: "reverseTokenRef";
            isMut: false;
            isSigner: false;
        }, {
            name: "tokenBonding";
            isMut: true;
            isSigner: false;
        }, {
            name: "tokenBondingAuthority";
            isMut: false;
            isSigner: false;
        }, {
            name: "owner";
            isMut: false;
            isSigner: true;
        }, {
            name: "tokenBondingProgram";
            isMut: false;
            isSigner: false;
        }, {
            name: "baseMint";
            isMut: false;
            isSigner: false;
        }, {
            name: "targetMint";
            isMut: false;
            isSigner: false;
        }, {
            name: "buyBaseRoyalties";
            isMut: false;
            isSigner: false;
        }, {
            name: "buyTargetRoyalties";
            isMut: false;
            isSigner: false;
        }, {
            name: "sellBaseRoyalties";
            isMut: false;
            isSigner: false;
        }, {
            name: "sellTargetRoyalties";
            isMut: false;
            isSigner: false;
        }];
        args: [{
            name: "args";
            type: {
                defined: "UpdateTokenBondingV0ArgsWrapper";
            };
        }];
    }>;
    get wallet(): import("@project-serum/anchor/dist/cjs/provider").Wallet;
    get account(): anchor.AccountNamespace<SplTokenCollectiveIDL>;
    get errors(): Map<number, string>;
    sendInstructions(instructions: TransactionInstruction[], signers: Signer[], payer?: PublicKey): Promise<string>;
    createCollectiveInstructions({ payer, mint, authority, mintAuthority, config, bonding, metadata }: CreateCollectiveArgs): Promise<BigInstructionResult<{
        collective: PublicKey;
        tokenBonding?: PublicKey;
    }>>;
    createCollective(args: CreateCollectiveArgs): Promise<{
        collective: PublicKey;
        tokenBonding?: PublicKey;
    }>;
    claimSocialTokenInstructions({ payer, owner, tokenRef, symbol, buyBaseRoyalties, buyTargetRoyalties, sellBaseRoyalties, sellTargetRoyalties, ignoreMissingName }: ClaimSocialTokenArgs): Promise<InstructionResult<null>>;
    claimSocialToken(args: ClaimSocialTokenArgs): Promise<void>;
    createSocialTokenInstructions({ ignoreIfExists, payer, collective, name, owner, tokenName, symbol, nameClass, nameParent, curve, tokenBondingParams }: CreateSocialTokenArgs): Promise<BigInstructionResult<{
        tokenRef: PublicKey;
        reverseTokenRef: PublicKey;
        tokenBonding: PublicKey;
    }>>;
    createSocialToken(args: CreateSocialTokenArgs): Promise<{
        tokenRef: PublicKey;
        reverseTokenRef: PublicKey;
        tokenBonding: PublicKey;
    }>;
}
//# sourceMappingURL=index.d.ts.map